.. Copyright 2015, 2018, 2023 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.layout
-----------------------

.. automodule:: reahl.web.layout


PageLayout
""""""""""

.. autoclass:: PageLayout
   :members:


